//
//  AsReaderBLEProtocol.h
//  AsReaderDockSDK
//
//  Created by MRX_ZYL on 27/1/2021.
//  Copyright © 2021 ZYL. All rights reserved.
//

#ifndef AsReaderBLEProtocols_h
#define AsReaderBLEProtocols_h
#import <CoreBluetooth/CoreBluetooth.h>

typedef NS_ENUM(NSUInteger, BleStatusCodes) {
    BLE_STS_SCANNING = 0x00,
    BLE_STS_SCAN_STOP = 0x01,
};


@protocol AsReaderBLEProtocols <NSObject>

@optional
/**
 *  @brief      Used in the APP.
 *  @details    This function reports information about discovered BLE devices.
 */
- (void)scanningBleDeive:(CBPeripheral*)device;

/**
 *  @brief      Used in the APP.
 *  @details    This function reports BLE search status.
 */
- (void)scanBleStatus:(BleStatusCodes)status;

@required
/**
 *  @brief      [ONLY SDK USE] Response of all
 *  @details    This function is called when receive data from the reader.
 *  @param      data : Data sent by the reader
 */
- (int)receive:(NSData *)data;

/**
 *  @brief      [ONLY SDK USE] Response of connection state
 *  @details    Called when open session, close session, connected and disconnected
 *  @param      status : connected (0), disconnected (1)
 */
- (void)plugChangedStatus:(int)status;
@end

#endif /* AsReaderBLEProtocol_h */
